## 0.9.0 - 2023-10-11

### Added

- [#944](https://github.com/edgarrmondragon/citric/issues/944) Add `Client.get_server_version`
- [#1005](https://github.com/edgarrmondragon/citric/issues/1005) Official support for Python 3.12

### Documentation

- [#934](https://github.com/edgarrmondragon/citric/issues/934) Report status of integration tests against multiple LimeSurvey versions
- [#964](https://github.com/edgarrmondragon/citric/issues/964) Fix GitHub archive URLs in integration test docs
- [#996](https://github.com/edgarrmondragon/citric/issues/996) Document current version in docs site
